@@ -35,7 +35,7 @@ def upsert(values: dict, session, table_name: str):
     for col in insert_statement.table.columns:
         col_name = col.name
         if col_name not in table_metadata.primary_key:
-            update_cols.update({col_name: getattr(insert_statement.inserted, col_name)})
+            update_cols.update({col_name: insert_statement.inserted[col_name]})
     upsert_statement = insert_statement.on_duplicate_key_update(**update_cols)
     try:
         session.execute(upsert_statement)
