@@ -15,3 +15,14 @@ def get_buffered_timestamp(timestamp: str, buffer_duration=BUFFER_DURATION_IN_MI
         minutes=buffer_duration,
     )
     return start.strftime("%Y-%m-%d %H:%M:%S")
+
+
+def get_interval_duration(start: datetime, end: datetime):
+    """
+    Calculates duration between two datetimes
+
+    :param start: timer start parameter
+    :param end: timer end parameter
+    :return:
+    """
+    return round((end - start).total_seconds())
